==> camel-k-quarkus-knative-1.3.0.fuse-jdk11-800012-redhat-00001-sources.jar: org/apache/camel/k/quarkus/knative/KnativeRecorder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.k.quarkus.knative;

import java.util.Collections;
import java.util.function.Supplier;

import io.quarkus.runtime.RuntimeValue;
import io.quarkus.runtime.annotations.Recorder;
import io.vertx.core.Handler;
import io.vertx.core.Vertx;
import io.vertx.ext.web.Router;
import io.vertx.ext.web.RoutingContext;
import org.apache.camel.component.knative.KnativeComponent;
import org.apache.camel.component.knative.http.KnativeHttpTransport;
import org.apache.camel.k.http.PlatformHttp;

@Recorder
public class KnativeRecorder {
    public RuntimeValue<KnativeComponent> createKnativeComponent(
        Supplier<Vertx> vertx,
        RuntimeValue<Router> router,
        Handler<RoutingContext> bodyHandler) {

        KnativeHttpTransport transport = new KnativeHttpTransport();
        transport.setPlatformHttp(new PlatformHttp(
            vertx.get(),
            router.getValue(),
            Collections.singletonList(bodyHandler)
        ));

        KnativeComponent component = new KnativeComponent();
        component.setTransport(transport);

        return new RuntimeValue<>(component);
    }
}

==> camel-k-quarkus-knative-1.5.0.fuse-jdk11-800010-redhat-00001-sources.jar: org/apache/camel/k/quarkus/knative/KnativeRecorder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.k.quarkus.knative;

import java.util.function.Supplier;

import io.quarkus.runtime.RuntimeValue;
import io.quarkus.runtime.annotations.Recorder;
import io.vertx.core.Handler;
import io.vertx.core.Vertx;
import io.vertx.ext.web.Router;
import io.vertx.ext.web.RoutingContext;
import org.apache.camel.component.knative.KnativeComponent;
import org.apache.camel.component.knative.http.KnativeHttpTransport;
import org.apache.camel.component.platform.http.vertx.VertxPlatformHttpRouter;

@Recorder
public class KnativeRecorder {
    public RuntimeValue<KnativeComponent> createKnativeComponent(
        Supplier<Vertx> vertx,
        RuntimeValue<Router> router,
        Handler<RoutingContext> bodyHandler) {

        KnativeHttpTransport transport = new KnativeHttpTransport();
        transport.setRouter(new VertxPlatformHttpRouter(vertx.get(), router.getValue()) {
            @Override
            public Handler<RoutingContext> bodyHandler() {
                return bodyHandler;
            }
        });

        KnativeComponent component = new KnativeComponent();
        component.setTransport(transport);

        return new RuntimeValue<>(component);
    }
}
